@@ -145,6 +145,7 @@ function uninstall_aur_packages() {
 function refactor_mirror_list() {
   install_official_packages pacman-contrib
 
+  echo "Sort /etc/pacman.d/mirrorlist by speed!"
   cp /etc/pacman.d/mirrorlist /etc/pacman.d/mirrorlist.backup
   rankmirrors -n 10 /etc/pacman.d/mirrorlist.backup > /etc/pacman.d/mirrorlist
 }
@@ -569,8 +570,7 @@ EOT
   }
 
   function gnome_bluetooth_user() {
-    uninstall_aur_packages gnome-bluetooth
-    install_aur_packages gnome-bluetooth-pantheon
+    yes | yay -S gnome-bluetooth-pantheon
   }
 
   function docker_system() {
@@ -760,6 +760,8 @@ EOT
     grub-mkconfig -o "/boot/grub/grub.cfg"
   fi
 
+  echo "Refresh Keys"
+  pacman-key --refresh-keys
 }
 
 function alis_admin_user() {
